# Cli

[Sigstickers Index](../README.md#sigstickers-index) / [Sigstickers](./index.md#sigstickers) / Cli

> Auto-generated documentation for [sigstickers.cli](../../../sigstickers/cli.py) module.

- [Cli](#cli)
  - [cli](#cli)
  - [main](#main)

## cli

[Show source in cli.py:18](../../../sigstickers/cli.py#L18)

CLI entry point.

#### Signature

```python
def cli() -> None: ...
```



## main

[Show source in cli.py:41](../../../sigstickers/cli.py#L41)

Download, and convert sticker packs.

#### Signature

```python
def main(packs: list[str], cwd: Path = DEFAULT_CWD) -> int: ...
```

#### See also

- [DEFAULT_CWD](./downloader.md#default_cwd)